#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Office 365 Address Lists.

Office 365 Address Lists

:copyright: (c) 2016 by Brad Gibson
:license: MIT, see LICENSE for more details
"""
from __future__ import absolute_import, unicode_literals

__title__ = 'Office 365 Address Lists'
__summary__ = 'Office 365 Address Lists'
__uri__ = 'https://github.com/napalm255/Office 365 Address Lists'

__version__ = '0.3.0'

__author__ = 'Brad Gibson'
__email__ = 'napalm255@gmail.com'

__license__ = 'MIT'
__copyright__ = 'Copyright 2016 Brad Gibson'
